pyparsing.pyparsing.SkipTo

Package pyparsing :: Module pyparsing :: Class SkipTo |
[frames] | no frames]

# Class SkipTo

source code

         object --+
                  |
      ParserElement --+
                      |
    ParseElementEnhance --+
                          |
                         SkipTo

Token for skipping over all undefined text until the matched expression is found. If include is set to true, the matched expression is also parsed (the skipped text and matched expression are returned as a 2-element list). The ignore argument is used to define grammars (typically quoted strings and comments) that might contain false matches.

Instance Methods
__init__(self, other, include=False, ignore=None, failOn=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
parseImpl(self, instring, loc, doActions=True) | source code
Inherited from `ParseElementEnhance`: `__str__`, `checkRecursion`, `ignore`, `leaveWhitespace`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__hash__`, `__invert__`, `__mul__`, `__ne__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__rne__`, `__ror__`, `__rsub__`, `__rxor__`, `__sub__`, `__xor__`, `addParseAction`, `copy`, `getException`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Static Methods
Inherited from `ParserElement`: `enablePackrat`, `resetCache`, `setDefaultWhitespaceChars`

Class Variables
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, other, include=False, ignore=None, failOn=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### parseImpl(self, instring, loc, doActions=True) | source code
Overrides: ParserElement.parseImpl